<style>.ig-b- { display: inline-block; }
.ig-b- img { visibility: hidden; }
.ig-b-:hover { background-position: 0 -60px; } .ig-b-:active { background-position: 0 -120px; }
.ig-b-{{ size|default_if_none:"32" }} { width: 32px; height: 32px; background: url(//badges.instagram.com/static/images/ig-badge-sprite-{{ size|default_if_none:"32" }}.png) no-repeat 0 0; }
@media only screen and (-webkit-min-device-pixel-ratio: 2), only screen and (min--moz-device-pixel-ratio: 2), only screen and (-o-min-device-pixel-ratio: 2 / 1), only screen and (min-device-pixel-ratio: 2), only screen and (min-resolution: 192dpi), only screen and (min-resolution: 2dppx) {
.ig-b-{{ size|default_if_none:"32" }} { background-image: url(//badges.instagram.com/static/images/ig-badge-sprite-{{ size|default_if_none:"32" }}@2x.png); background-size: 60px 178px; } }</style>
<a href="http://instagram.com/{{ username }}?ref=badge" class="ig-b- ig-b-{{ size|default_if_none:"32" }}"><img src="//badges.instagram.com/static/images/ig-badge-{{ size|default_if_none:"32" }}.png" alt="Instagram" /></a>
