{% load social_widgets %}
{% block javascript %}
{% if nojs or widget_service in social_widgets_javascript %}
   {# Do not load JavaScript then #}
{% else %}
    <div id="fb-root"></div>
    <script>(function(d, s, id) {
      var js, fjs = d.getElementsByTagName(s)[0];
      if (d.getElementById(id)) return;
      js = d.createElement(s); js.id = id;
      js.src = "//connect.facebook.net/{{ locale }}/sdk.js#xfbml=1{% if app_id %}&appId={{ app_id }}{% endif %}&version=v2.0";
      fjs.parentNode.insertBefore(js, fjs);
    }(document, 'script', 'facebook-jssdk'));</script>
{% endif %}
{% endblock javascript %}
{% block widget %}
{% endblock widget %}
